# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .me import (
    MeResource,
    AsyncMeResource,
    MeResourceWithRawResponse,
    AsyncMeResourceWithRawResponse,
    MeResourceWithStreamingResponse,
    AsyncMeResourceWithStreamingResponse,
)
from .users import (
    UsersResource,
    AsyncUsersResource,
    UsersResourceWithRawResponse,
    AsyncUsersResourceWithRawResponse,
    UsersResourceWithStreamingResponse,
    AsyncUsersResourceWithStreamingResponse,
)

__all__ = [
    "MeResource",
    "AsyncMeResource",
    "MeResourceWithRawResponse",
    "AsyncMeResourceWithRawResponse",
    "MeResourceWithStreamingResponse",
    "AsyncMeResourceWithStreamingResponse",
    "UsersResource",
    "AsyncUsersResource",
    "UsersResourceWithRawResponse",
    "AsyncUsersResourceWithRawResponse",
    "UsersResourceWithStreamingResponse",
    "AsyncUsersResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["TreasuryForecastCashFlowParams"]


class TreasuryForecastCashFlowParams(TypedDict, total=False):
    forecast_horizon_days: Annotated[int, PropertyInfo(alias="forecastHorizonDays")]
    """
    The number of days into the future for which to generate the cash flow forecast
    (e.g., 30, 90, 180).
    """

    include_scenario_analysis: Annotated[bool, PropertyInfo(alias="includeScenarioAnalysis")]
    """
    If true, the forecast will include best-case and worst-case scenario analysis
    alongside the most likely projection.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Query, Headers, NotGiven, not_given
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options

__all__ = ["AuditsResource", "AsyncAuditsResource"]


class AuditsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AuditsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/diplomat-bit/aibank#accessing-raw-response-data-eg-headers
        """
        return AuditsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AuditsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/diplomat-bit/aibank#with_streaming_response
        """
        return AuditsResourceWithStreamingResponse(self)

    def request(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Initiates an AI-powered compliance audit for a specific period or scope,
        generating a comprehensive report detailing adherence to regulatory frameworks,
        internal policies, and flagging potential risks.
        """
        return self._post(
            "/corporate/compliance/audits",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AsyncAuditsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAuditsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/diplomat-bit/aibank#accessing-raw-response-data-eg-headers
        """
        return AsyncAuditsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAuditsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/diplomat-bit/aibank#with_streaming_response
        """
        return AsyncAuditsResourceWithStreamingResponse(self)

    async def request(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Initiates an AI-powered compliance audit for a specific period or scope,
        generating a comprehensive report detailing adherence to regulatory frameworks,
        internal policies, and flagging potential risks.
        """
        return await self._post(
            "/corporate/compliance/audits",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AuditsResourceWithRawResponse:
    def __init__(self, audits: AuditsResource) -> None:
        self._audits = audits

        self.request = to_raw_response_wrapper(
            audits.request,
        )


class AsyncAuditsResourceWithRawResponse:
    def __init__(self, audits: AsyncAuditsResource) -> None:
        self._audits = audits

        self.request = async_to_raw_response_wrapper(
            audits.request,
        )


class AuditsResourceWithStreamingResponse:
    def __init__(self, audits: AuditsResource) -> None:
        self._audits = audits

        self.request = to_streamed_response_wrapper(
            audits.request,
        )


class AsyncAuditsResourceWithStreamingResponse:
    def __init__(self, audits: AsyncAuditsResource) -> None:
        self._audits = audits

        self.request = async_to_streamed_response_wrapper(
            audits.request,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["TreasuryForecastCashFlowResponse"]


class TreasuryForecastCashFlowResponse(BaseModel):
    inflow_forecast: object = FieldInfo(alias="inflowForecast")
    """Forecast of cash inflows by source."""

    outflow_forecast: object = FieldInfo(alias="outflowForecast")
    """Forecast of cash outflows by category."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .ai import (
    AIResource,
    AsyncAIResource,
    AIResourceWithRawResponse,
    AsyncAIResourceWithRawResponse,
    AIResourceWithStreamingResponse,
    AsyncAIResourceWithStreamingResponse,
)
from .web3 import (
    Web3Resource,
    AsyncWeb3Resource,
    Web3ResourceWithRawResponse,
    AsyncWeb3ResourceWithRawResponse,
    Web3ResourceWithStreamingResponse,
    AsyncWeb3ResourceWithStreamingResponse,
)
from .users import (
    UsersResource,
    AsyncUsersResource,
    UsersResourceWithRawResponse,
    AsyncUsersResourceWithRawResponse,
    UsersResourceWithStreamingResponse,
    AsyncUsersResourceWithStreamingResponse,
)
from .accounts import (
    AccountsResource,
    AsyncAccountsResource,
    AccountsResourceWithRawResponse,
    AsyncAccountsResourceWithRawResponse,
    AccountsResourceWithStreamingResponse,
    AsyncAccountsResourceWithStreamingResponse,
)
from .payments import (
    PaymentsResource,
    AsyncPaymentsResource,
    PaymentsResourceWithRawResponse,
    AsyncPaymentsResourceWithRawResponse,
    PaymentsResourceWithStreamingResponse,
    AsyncPaymentsResourceWithStreamingResponse,
)
from .corporate import (
    CorporateResource,
    AsyncCorporateResource,
    CorporateResourceWithRawResponse,
    AsyncCorporateResourceWithRawResponse,
    CorporateResourceWithStreamingResponse,
    AsyncCorporateResourceWithStreamingResponse,
)
from .marketplace import (
    MarketplaceResource,
    AsyncMarketplaceResource,
    MarketplaceResourceWithRawResponse,
    AsyncMarketplaceResourceWithRawResponse,
    MarketplaceResourceWithStreamingResponse,
    AsyncMarketplaceResourceWithStreamingResponse,
)
from .transactions import (
    TransactionsResource,
    AsyncTransactionsResource,
    TransactionsResourceWithRawResponse,
    AsyncTransactionsResourceWithRawResponse,
    TransactionsResourceWithStreamingResponse,
    AsyncTransactionsResourceWithStreamingResponse,
)
from .sustainability import (
    SustainabilityResource,
    AsyncSustainabilityResource,
    SustainabilityResourceWithRawResponse,
    AsyncSustainabilityResourceWithRawResponse,
    SustainabilityResourceWithStreamingResponse,
    AsyncSustainabilityResourceWithStreamingResponse,
)

__all__ = [
    "UsersResource",
    "AsyncUsersResource",
    "UsersResourceWithRawResponse",
    "AsyncUsersResourceWithRawResponse",
    "UsersResourceWithStreamingResponse",
    "AsyncUsersResourceWithStreamingResponse",
    "AccountsResource",
    "AsyncAccountsResource",
    "AccountsResourceWithRawResponse",
    "AsyncAccountsResourceWithRawResponse",
    "AccountsResourceWithStreamingResponse",
    "AsyncAccountsResourceWithStreamingResponse",
    "TransactionsResource",
    "AsyncTransactionsResource",
    "TransactionsResourceWithRawResponse",
    "AsyncTransactionsResourceWithRawResponse",
    "TransactionsResourceWithStreamingResponse",
    "AsyncTransactionsResourceWithStreamingResponse",
    "AIResource",
    "AsyncAIResource",
    "AIResourceWithRawResponse",
    "AsyncAIResourceWithRawResponse",
    "AIResourceWithStreamingResponse",
    "AsyncAIResourceWithStreamingResponse",
    "CorporateResource",
    "AsyncCorporateResource",
    "CorporateResourceWithRawResponse",
    "AsyncCorporateResourceWithRawResponse",
    "CorporateResourceWithStreamingResponse",
    "AsyncCorporateResourceWithStreamingResponse",
    "Web3Resource",
    "AsyncWeb3Resource",
    "Web3ResourceWithRawResponse",
    "AsyncWeb3ResourceWithRawResponse",
    "Web3ResourceWithStreamingResponse",
    "AsyncWeb3ResourceWithStreamingResponse",
    "PaymentsResource",
    "AsyncPaymentsResource",
    "PaymentsResourceWithRawResponse",
    "AsyncPaymentsResourceWithRawResponse",
    "PaymentsResourceWithStreamingResponse",
    "AsyncPaymentsResourceWithStreamingResponse",
    "SustainabilityResource",
    "AsyncSustainabilityResource",
    "SustainabilityResourceWithRawResponse",
    "AsyncSustainabilityResourceWithRawResponse",
    "SustainabilityResourceWithStreamingResponse",
    "AsyncSustainabilityResourceWithStreamingResponse",
    "MarketplaceResource",
    "AsyncMarketplaceResource",
    "MarketplaceResourceWithRawResponse",
    "AsyncMarketplaceResourceWithRawResponse",
    "MarketplaceResourceWithStreamingResponse",
    "AsyncMarketplaceResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .ai import (
    AIResource,
    AsyncAIResource,
    AIResourceWithRawResponse,
    AsyncAIResourceWithRawResponse,
    AIResourceWithStreamingResponse,
    AsyncAIResourceWithStreamingResponse,
)
from .oracle import (
    OracleResource,
    AsyncOracleResource,
    OracleResourceWithRawResponse,
    AsyncOracleResourceWithRawResponse,
    OracleResourceWithStreamingResponse,
    AsyncOracleResourceWithStreamingResponse,
)
from .advisor import (
    AdvisorResource,
    AsyncAdvisorResource,
    AdvisorResourceWithRawResponse,
    AsyncAdvisorResourceWithRawResponse,
    AdvisorResourceWithStreamingResponse,
    AsyncAdvisorResourceWithStreamingResponse,
)
from .incubator import (
    IncubatorResource,
    AsyncIncubatorResource,
    IncubatorResourceWithRawResponse,
    AsyncIncubatorResourceWithRawResponse,
    IncubatorResourceWithStreamingResponse,
    AsyncIncubatorResourceWithStreamingResponse,
)

__all__ = [
    "AdvisorResource",
    "AsyncAdvisorResource",
    "AdvisorResourceWithRawResponse",
    "AsyncAdvisorResourceWithRawResponse",
    "AdvisorResourceWithStreamingResponse",
    "AsyncAdvisorResourceWithStreamingResponse",
    "OracleResource",
    "AsyncOracleResource",
    "OracleResourceWithRawResponse",
    "AsyncOracleResourceWithRawResponse",
    "OracleResourceWithStreamingResponse",
    "AsyncOracleResourceWithStreamingResponse",
    "IncubatorResource",
    "AsyncIncubatorResource",
    "IncubatorResourceWithRawResponse",
    "AsyncIncubatorResourceWithRawResponse",
    "IncubatorResourceWithStreamingResponse",
    "AsyncIncubatorResourceWithStreamingResponse",
    "AIResource",
    "AsyncAIResource",
    "AIResourceWithRawResponse",
    "AsyncAIResourceWithRawResponse",
    "AIResourceWithStreamingResponse",
    "AsyncAIResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from jocall3 import Jocall3, AsyncJocall3
from tests.utils import assert_matches_type
from jocall3.types.payments import FxGetRatesResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestFx:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_convert(self, client: Jocall3) -> None:
        fx = client.payments.fx.convert()
        assert_matches_type(object, fx, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_convert(self, client: Jocall3) -> None:
        response = client.payments.fx.with_raw_response.convert()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        fx = response.parse()
        assert_matches_type(object, fx, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_convert(self, client: Jocall3) -> None:
        with client.payments.fx.with_streaming_response.convert() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            fx = response.parse()
            assert_matches_type(object, fx, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_rates(self, client: Jocall3) -> None:
        fx = client.payments.fx.get_rates()
        assert_matches_type(FxGetRatesResponse, fx, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_rates_with_all_params(self, client: Jocall3) -> None:
        fx = client.payments.fx.get_rates(
            base_currency="baseCurrency",
            forecast_days=0,
            target_currency="targetCurrency",
        )
        assert_matches_type(FxGetRatesResponse, fx, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_rates(self, client: Jocall3) -> None:
        response = client.payments.fx.with_raw_response.get_rates()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        fx = response.parse()
        assert_matches_type(FxGetRatesResponse, fx, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_rates(self, client: Jocall3) -> None:
        with client.payments.fx.with_streaming_response.get_rates() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            fx = response.parse()
            assert_matches_type(FxGetRatesResponse, fx, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncFx:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_convert(self, async_client: AsyncJocall3) -> None:
        fx = await async_client.payments.fx.convert()
        assert_matches_type(object, fx, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_convert(self, async_client: AsyncJocall3) -> None:
        response = await async_client.payments.fx.with_raw_response.convert()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        fx = await response.parse()
        assert_matches_type(object, fx, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_convert(self, async_client: AsyncJocall3) -> None:
        async with async_client.payments.fx.with_streaming_response.convert() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            fx = await response.parse()
            assert_matches_type(object, fx, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_rates(self, async_client: AsyncJocall3) -> None:
        fx = await async_client.payments.fx.get_rates()
        assert_matches_type(FxGetRatesResponse, fx, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_rates_with_all_params(self, async_client: AsyncJocall3) -> None:
        fx = await async_client.payments.fx.get_rates(
            base_currency="baseCurrency",
            forecast_days=0,
            target_currency="targetCurrency",
        )
        assert_matches_type(FxGetRatesResponse, fx, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_rates(self, async_client: AsyncJocall3) -> None:
        response = await async_client.payments.fx.with_raw_response.get_rates()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        fx = await response.parse()
        assert_matches_type(FxGetRatesResponse, fx, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_rates(self, async_client: AsyncJocall3) -> None:
        async with async_client.payments.fx.with_streaming_response.get_rates() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            fx = await response.parse()
            assert_matches_type(FxGetRatesResponse, fx, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["CardIssueVirtualParams"]


class CardIssueVirtualParams(TypedDict, total=False):
    controls: Required[object]
    """Granular spending controls for a corporate card."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["FxGetRatesResponse"]


class FxGetRatesResponse(BaseModel):
    current_rate: object = FieldInfo(alias="currentRate")
    """Real-time foreign exchange rates."""

    historical_volatility: Optional[object] = FieldInfo(alias="historicalVolatility", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["StatementListResponse"]


class StatementListResponse(BaseModel):
    download_urls: object = FieldInfo(alias="downloadUrls")
    """Map of available download URLs for different formats."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .accounts import (
    AccountsResource,
    AsyncAccountsResource,
    AccountsResourceWithRawResponse,
    AsyncAccountsResourceWithRawResponse,
    AccountsResourceWithStreamingResponse,
    AsyncAccountsResourceWithStreamingResponse,
)
from .overdraft import (
    OverdraftResource,
    AsyncOverdraftResource,
    OverdraftResourceWithRawResponse,
    AsyncOverdraftResourceWithRawResponse,
    OverdraftResourceWithStreamingResponse,
    AsyncOverdraftResourceWithStreamingResponse,
)
from .statements import (
    StatementsResource,
    AsyncStatementsResource,
    StatementsResourceWithRawResponse,
    AsyncStatementsResourceWithRawResponse,
    StatementsResourceWithStreamingResponse,
    AsyncStatementsResourceWithStreamingResponse,
)
from .transactions import (
    TransactionsResource,
    AsyncTransactionsResource,
    TransactionsResourceWithRawResponse,
    AsyncTransactionsResourceWithRawResponse,
    TransactionsResourceWithStreamingResponse,
    AsyncTransactionsResourceWithStreamingResponse,
)

__all__ = [
    "TransactionsResource",
    "AsyncTransactionsResource",
    "TransactionsResourceWithRawResponse",
    "AsyncTransactionsResourceWithRawResponse",
    "TransactionsResourceWithStreamingResponse",
    "AsyncTransactionsResourceWithStreamingResponse",
    "StatementsResource",
    "AsyncStatementsResource",
    "StatementsResourceWithRawResponse",
    "AsyncStatementsResourceWithRawResponse",
    "StatementsResourceWithStreamingResponse",
    "AsyncStatementsResourceWithStreamingResponse",
    "OverdraftResource",
    "AsyncOverdraftResource",
    "OverdraftResourceWithRawResponse",
    "AsyncOverdraftResourceWithRawResponse",
    "OverdraftResourceWithStreamingResponse",
    "AsyncOverdraftResourceWithStreamingResponse",
    "AccountsResource",
    "AsyncAccountsResource",
    "AccountsResourceWithRawResponse",
    "AsyncAccountsResourceWithRawResponse",
    "AccountsResourceWithStreamingResponse",
    "AsyncAccountsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["WalletGetBalanceParams"]


class WalletGetBalanceParams(TypedDict, total=False):
    limit: int
    """Maximum number of items to return in a single page."""

    offset: int
    """Number of items to skip before starting to collect the result set."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .advisor_chat_params import AdvisorChatParams as AdvisorChatParams
from .incubator_generate_pitch_params import IncubatorGeneratePitchParams as IncubatorGeneratePitchParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Query, Headers, NotGiven, not_given
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options

__all__ = ["BiometricsResource", "AsyncBiometricsResource"]


class BiometricsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> BiometricsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/diplomat-bit/aibank#accessing-raw-response-data-eg-headers
        """
        return BiometricsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> BiometricsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/diplomat-bit/aibank#with_streaming_response
        """
        return BiometricsResourceWithStreamingResponse(self)

    def retrieve_status(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Retrieves the current status of biometric enrollments for the authenticated
        user.
        """
        return self._get(
            "/users/me/biometrics",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def verify(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Performs real-time biometric verification to authorize sensitive actions or
        access protected resources, using a one-time biometric signature.
        """
        return self._post(
            "/users/me/biometrics/verify",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AsyncBiometricsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncBiometricsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/diplomat-bit/aibank#accessing-raw-response-data-eg-headers
        """
        return AsyncBiometricsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncBiometricsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/diplomat-bit/aibank#with_streaming_response
        """
        return AsyncBiometricsResourceWithStreamingResponse(self)

    async def retrieve_status(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Retrieves the current status of biometric enrollments for the authenticated
        user.
        """
        return await self._get(
            "/users/me/biometrics",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def verify(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Performs real-time biometric verification to authorize sensitive actions or
        access protected resources, using a one-time biometric signature.
        """
        return await self._post(
            "/users/me/biometrics/verify",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class BiometricsResourceWithRawResponse:
    def __init__(self, biometrics: BiometricsResource) -> None:
        self._biometrics = biometrics

        self.retrieve_status = to_raw_response_wrapper(
            biometrics.retrieve_status,
        )
        self.verify = to_raw_response_wrapper(
            biometrics.verify,
        )


class AsyncBiometricsResourceWithRawResponse:
    def __init__(self, biometrics: AsyncBiometricsResource) -> None:
        self._biometrics = biometrics

        self.retrieve_status = async_to_raw_response_wrapper(
            biometrics.retrieve_status,
        )
        self.verify = async_to_raw_response_wrapper(
            biometrics.verify,
        )


class BiometricsResourceWithStreamingResponse:
    def __init__(self, biometrics: BiometricsResource) -> None:
        self._biometrics = biometrics

        self.retrieve_status = to_streamed_response_wrapper(
            biometrics.retrieve_status,
        )
        self.verify = to_streamed_response_wrapper(
            biometrics.verify,
        )


class AsyncBiometricsResourceWithStreamingResponse:
    def __init__(self, biometrics: AsyncBiometricsResource) -> None:
        self._biometrics = biometrics

        self.retrieve_status = async_to_streamed_response_wrapper(
            biometrics.retrieve_status,
        )
        self.verify = async_to_streamed_response_wrapper(
            biometrics.verify,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .simulate import (
    SimulateResource,
    AsyncSimulateResource,
    SimulateResourceWithRawResponse,
    AsyncSimulateResourceWithRawResponse,
    SimulateResourceWithStreamingResponse,
    AsyncSimulateResourceWithStreamingResponse,
)
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["OracleResource", "AsyncOracleResource"]


class OracleResource(SyncAPIResource):
    @cached_property
    def simulate(self) -> SimulateResource:
        return SimulateResource(self._client)

    @cached_property
    def with_raw_response(self) -> OracleResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/diplomat-bit/aibank#accessing-raw-response-data-eg-headers
        """
        return OracleResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> OracleResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/diplomat-bit/aibank#with_streaming_response
        """
        return OracleResourceWithStreamingResponse(self)


class AsyncOracleResource(AsyncAPIResource):
    @cached_property
    def simulate(self) -> AsyncSimulateResource:
        return AsyncSimulateResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncOracleResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/diplomat-bit/aibank#accessing-raw-response-data-eg-headers
        """
        return AsyncOracleResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncOracleResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/diplomat-bit/aibank#with_streaming_response
        """
        return AsyncOracleResourceWithStreamingResponse(self)


class OracleResourceWithRawResponse:
    def __init__(self, oracle: OracleResource) -> None:
        self._oracle = oracle

    @cached_property
    def simulate(self) -> SimulateResourceWithRawResponse:
        return SimulateResourceWithRawResponse(self._oracle.simulate)


class AsyncOracleResourceWithRawResponse:
    def __init__(self, oracle: AsyncOracleResource) -> None:
        self._oracle = oracle

    @cached_property
    def simulate(self) -> AsyncSimulateResourceWithRawResponse:
        return AsyncSimulateResourceWithRawResponse(self._oracle.simulate)


class OracleResourceWithStreamingResponse:
    def __init__(self, oracle: OracleResource) -> None:
        self._oracle = oracle

    @cached_property
    def simulate(self) -> SimulateResourceWithStreamingResponse:
        return SimulateResourceWithStreamingResponse(self._oracle.simulate)


class AsyncOracleResourceWithStreamingResponse:
    def __init__(self, oracle: AsyncOracleResource) -> None:
        self._oracle = oracle

    @cached_property
    def simulate(self) -> AsyncSimulateResourceWithStreamingResponse:
        return AsyncSimulateResourceWithStreamingResponse(self._oracle.simulate)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .fx import (
    FxResource,
    AsyncFxResource,
    FxResourceWithRawResponse,
    AsyncFxResourceWithRawResponse,
    FxResourceWithStreamingResponse,
    AsyncFxResourceWithStreamingResponse,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["PaymentsResource", "AsyncPaymentsResource"]


class PaymentsResource(SyncAPIResource):
    @cached_property
    def fx(self) -> FxResource:
        return FxResource(self._client)

    @cached_property
    def with_raw_response(self) -> PaymentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/diplomat-bit/aibank#accessing-raw-response-data-eg-headers
        """
        return PaymentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PaymentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/diplomat-bit/aibank#with_streaming_response
        """
        return PaymentsResourceWithStreamingResponse(self)


class AsyncPaymentsResource(AsyncAPIResource):
    @cached_property
    def fx(self) -> AsyncFxResource:
        return AsyncFxResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncPaymentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/diplomat-bit/aibank#accessing-raw-response-data-eg-headers
        """
        return AsyncPaymentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPaymentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/diplomat-bit/aibank#with_streaming_response
        """
        return AsyncPaymentsResourceWithStreamingResponse(self)


class PaymentsResourceWithRawResponse:
    def __init__(self, payments: PaymentsResource) -> None:
        self._payments = payments

    @cached_property
    def fx(self) -> FxResourceWithRawResponse:
        return FxResourceWithRawResponse(self._payments.fx)


class AsyncPaymentsResourceWithRawResponse:
    def __init__(self, payments: AsyncPaymentsResource) -> None:
        self._payments = payments

    @cached_property
    def fx(self) -> AsyncFxResourceWithRawResponse:
        return AsyncFxResourceWithRawResponse(self._payments.fx)


class PaymentsResourceWithStreamingResponse:
    def __init__(self, payments: PaymentsResource) -> None:
        self._payments = payments

    @cached_property
    def fx(self) -> FxResourceWithStreamingResponse:
        return FxResourceWithStreamingResponse(self._payments.fx)


class AsyncPaymentsResourceWithStreamingResponse:
    def __init__(self, payments: AsyncPaymentsResource) -> None:
        self._payments = payments

    @cached_property
    def fx(self) -> AsyncFxResourceWithStreamingResponse:
        return AsyncFxResourceWithStreamingResponse(self._payments.fx)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["SimulateRunStandardResponse"]


class SimulateRunStandardResponse(BaseModel):
    risk_analysis: Optional[object] = FieldInfo(alias="riskAnalysis", default=None)
    """AI-driven risk assessment of the simulated scenario."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .me_update_params import MeUpdateParams as MeUpdateParams
from .me_update_response import MeUpdateResponse as MeUpdateResponse
from .me_retrieve_response import MeRetrieveResponse as MeRetrieveResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .me import (
    MeResource,
    AsyncMeResource,
    MeResourceWithRawResponse,
    AsyncMeResourceWithRawResponse,
    MeResourceWithStreamingResponse,
    AsyncMeResourceWithStreamingResponse,
)
from .devices import (
    DevicesResource,
    AsyncDevicesResource,
    DevicesResourceWithRawResponse,
    AsyncDevicesResourceWithRawResponse,
    DevicesResourceWithStreamingResponse,
    AsyncDevicesResourceWithStreamingResponse,
)
from .biometrics import (
    BiometricsResource,
    AsyncBiometricsResource,
    BiometricsResourceWithRawResponse,
    AsyncBiometricsResourceWithRawResponse,
    BiometricsResourceWithStreamingResponse,
    AsyncBiometricsResourceWithStreamingResponse,
)

__all__ = [
    "DevicesResource",
    "AsyncDevicesResource",
    "DevicesResourceWithRawResponse",
    "AsyncDevicesResourceWithRawResponse",
    "DevicesResourceWithStreamingResponse",
    "AsyncDevicesResourceWithStreamingResponse",
    "BiometricsResource",
    "AsyncBiometricsResource",
    "BiometricsResourceWithRawResponse",
    "AsyncBiometricsResourceWithRawResponse",
    "BiometricsResourceWithStreamingResponse",
    "AsyncBiometricsResourceWithStreamingResponse",
    "MeResource",
    "AsyncMeResource",
    "MeResourceWithRawResponse",
    "AsyncMeResourceWithRawResponse",
    "MeResourceWithStreamingResponse",
    "AsyncMeResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .card_list_params import CardListParams as CardListParams
from .card_freeze_response import CardFreezeResponse as CardFreezeResponse
from .card_issue_virtual_params import CardIssueVirtualParams as CardIssueVirtualParams
from .card_issue_virtual_response import CardIssueVirtualResponse as CardIssueVirtualResponse
from .treasury_forecast_cash_flow_params import TreasuryForecastCashFlowParams as TreasuryForecastCashFlowParams
from .treasury_forecast_cash_flow_response import TreasuryForecastCashFlowResponse as TreasuryForecastCashFlowResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.ai.oracle import simulate_run_advanced_params
from ....types.ai.oracle.simulate_run_standard_response import SimulateRunStandardResponse

__all__ = ["SimulateResource", "AsyncSimulateResource"]


class SimulateResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SimulateResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/diplomat-bit/aibank#accessing-raw-response-data-eg-headers
        """
        return SimulateResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SimulateResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/diplomat-bit/aibank#with_streaming_response
        """
        return SimulateResourceWithStreamingResponse(self)

    def run_advanced(
        self,
        *,
        global_economic_factors: object | Omit = omit,
        personal_assumptions: object | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Engages the Quantum Oracle for highly complex, multi-variable simulations,
        allowing precise control over numerous financial parameters, market conditions,
        and personal events to generate deep, predictive insights and sensitivity
        analysis.

        Args:
          global_economic_factors: Optional: Global economic conditions to apply to all scenarios.

          personal_assumptions: Optional: Personal financial assumptions to override defaults.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/ai/oracle/simulate/advanced",
            body=maybe_transform(
                {
                    "global_economic_factors": global_economic_factors,
                    "personal_assumptions": personal_assumptions,
                },
                simulate_run_advanced_params.SimulateRunAdvancedParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def run_standard(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SimulateRunStandardResponse:
        """
        Submits a hypothetical scenario to the Quantum Oracle AI for standard financial
        impact analysis. The AI simulates the effect on the user's current financial
        state and provides a summary.
        """
        return self._post(
            "/ai/oracle/simulate",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SimulateRunStandardResponse,
        )


class AsyncSimulateResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSimulateResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/diplomat-bit/aibank#accessing-raw-response-data-eg-headers
        """
        return AsyncSimulateResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSimulateResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/diplomat-bit/aibank#with_streaming_response
        """
        return AsyncSimulateResourceWithStreamingResponse(self)

    async def run_advanced(
        self,
        *,
        global_economic_factors: object | Omit = omit,
        personal_assumptions: object | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Engages the Quantum Oracle for highly complex, multi-variable simulations,
        allowing precise control over numerous financial parameters, market conditions,
        and personal events to generate deep, predictive insights and sensitivity
        analysis.

        Args:
          global_economic_factors: Optional: Global economic conditions to apply to all scenarios.

          personal_assumptions: Optional: Personal financial assumptions to override defaults.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/ai/oracle/simulate/advanced",
            body=await async_maybe_transform(
                {
                    "global_economic_factors": global_economic_factors,
                    "personal_assumptions": personal_assumptions,
                },
                simulate_run_advanced_params.SimulateRunAdvancedParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def run_standard(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SimulateRunStandardResponse:
        """
        Submits a hypothetical scenario to the Quantum Oracle AI for standard financial
        impact analysis. The AI simulates the effect on the user's current financial
        state and provides a summary.
        """
        return await self._post(
            "/ai/oracle/simulate",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SimulateRunStandardResponse,
        )


class SimulateResourceWithRawResponse:
    def __init__(self, simulate: SimulateResource) -> None:
        self._simulate = simulate

        self.run_advanced = to_raw_response_wrapper(
            simulate.run_advanced,
        )
        self.run_standard = to_raw_response_wrapper(
            simulate.run_standard,
        )


class AsyncSimulateResourceWithRawResponse:
    def __init__(self, simulate: AsyncSimulateResource) -> None:
        self._simulate = simulate

        self.run_advanced = async_to_raw_response_wrapper(
            simulate.run_advanced,
        )
        self.run_standard = async_to_raw_response_wrapper(
            simulate.run_standard,
        )


class SimulateResourceWithStreamingResponse:
    def __init__(self, simulate: SimulateResource) -> None:
        self._simulate = simulate

        self.run_advanced = to_streamed_response_wrapper(
            simulate.run_advanced,
        )
        self.run_standard = to_streamed_response_wrapper(
            simulate.run_standard,
        )


class AsyncSimulateResourceWithStreamingResponse:
    def __init__(self, simulate: AsyncSimulateResource) -> None:
        self._simulate = simulate

        self.run_advanced = async_to_streamed_response_wrapper(
            simulate.run_advanced,
        )
        self.run_standard = async_to_streamed_response_wrapper(
            simulate.run_standard,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .insights import (
    InsightsResource,
    AsyncInsightsResource,
    InsightsResourceWithRawResponse,
    AsyncInsightsResourceWithRawResponse,
    InsightsResourceWithStreamingResponse,
    AsyncInsightsResourceWithStreamingResponse,
)
from .recurring import (
    RecurringResource,
    AsyncRecurringResource,
    RecurringResourceWithRawResponse,
    AsyncRecurringResourceWithRawResponse,
    RecurringResourceWithStreamingResponse,
    AsyncRecurringResourceWithStreamingResponse,
)
from .transactions import (
    TransactionsResource,
    AsyncTransactionsResource,
    TransactionsResourceWithRawResponse,
    AsyncTransactionsResourceWithRawResponse,
    TransactionsResourceWithStreamingResponse,
    AsyncTransactionsResourceWithStreamingResponse,
)

__all__ = [
    "RecurringResource",
    "AsyncRecurringResource",
    "RecurringResourceWithRawResponse",
    "AsyncRecurringResourceWithRawResponse",
    "RecurringResourceWithStreamingResponse",
    "AsyncRecurringResourceWithStreamingResponse",
    "InsightsResource",
    "AsyncInsightsResource",
    "InsightsResourceWithRawResponse",
    "AsyncInsightsResourceWithRawResponse",
    "InsightsResourceWithStreamingResponse",
    "AsyncInsightsResourceWithStreamingResponse",
    "TransactionsResource",
    "AsyncTransactionsResource",
    "TransactionsResourceWithRawResponse",
    "AsyncTransactionsResourceWithRawResponse",
    "TransactionsResourceWithStreamingResponse",
    "AsyncTransactionsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .offers import (
    OffersResource,
    AsyncOffersResource,
    OffersResourceWithRawResponse,
    AsyncOffersResourceWithRawResponse,
    OffersResourceWithStreamingResponse,
    AsyncOffersResourceWithStreamingResponse,
)
from ...types import marketplace_list_products_params
from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options

__all__ = ["MarketplaceResource", "AsyncMarketplaceResource"]


class MarketplaceResource(SyncAPIResource):
    @cached_property
    def offers(self) -> OffersResource:
        return OffersResource(self._client)

    @cached_property
    def with_raw_response(self) -> MarketplaceResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/diplomat-bit/aibank#accessing-raw-response-data-eg-headers
        """
        return MarketplaceResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> MarketplaceResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/diplomat-bit/aibank#with_streaming_response
        """
        return MarketplaceResourceWithStreamingResponse(self)

    def list_products(
        self,
        *,
        ai_personalization_level: str | Omit = omit,
        category: str | Omit = omit,
        limit: int | Omit = omit,
        min_rating: int | Omit = omit,
        offset: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Retrieves a personalized, AI-curated list of products and services from the
        Plato AI marketplace, tailored to the user's financial profile, goals, and
        spending patterns. Includes options for filtering and advanced search.

        Args:
          ai_personalization_level: Filter by AI personalization level (e.g., low, medium, high). 'High' means
              highly relevant to user's specific needs.

          category: Filter products by category (e.g., loans, insurance, credit_cards, investments).

          limit: Maximum number of items to return in a single page.

          min_rating: Minimum user rating for products (0-5).

          offset: Number of items to skip before starting to collect the result set.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/marketplace/products",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "ai_personalization_level": ai_personalization_level,
                        "category": category,
                        "limit": limit,
                        "min_rating": min_rating,
                        "offset": offset,
                    },
                    marketplace_list_products_params.MarketplaceListProductsParams,
                ),
            ),
            cast_to=object,
        )


class AsyncMarketplaceResource(AsyncAPIResource):
    @cached_property
    def offers(self) -> AsyncOffersResource:
        return AsyncOffersResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncMarketplaceResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/diplomat-bit/aibank#accessing-raw-response-data-eg-headers
        """
        return AsyncMarketplaceResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMarketplaceResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/diplomat-bit/aibank#with_streaming_response
        """
        return AsyncMarketplaceResourceWithStreamingResponse(self)

    async def list_products(
        self,
        *,
        ai_personalization_level: str | Omit = omit,
        category: str | Omit = omit,
        limit: int | Omit = omit,
        min_rating: int | Omit = omit,
        offset: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Retrieves a personalized, AI-curated list of products and services from the
        Plato AI marketplace, tailored to the user's financial profile, goals, and
        spending patterns. Includes options for filtering and advanced search.

        Args:
          ai_personalization_level: Filter by AI personalization level (e.g., low, medium, high). 'High' means
              highly relevant to user's specific needs.

          category: Filter products by category (e.g., loans, insurance, credit_cards, investments).

          limit: Maximum number of items to return in a single page.

          min_rating: Minimum user rating for products (0-5).

          offset: Number of items to skip before starting to collect the result set.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/marketplace/products",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "ai_personalization_level": ai_personalization_level,
                        "category": category,
                        "limit": limit,
                        "min_rating": min_rating,
                        "offset": offset,
                    },
                    marketplace_list_products_params.MarketplaceListProductsParams,
                ),
            ),
            cast_to=object,
        )


class MarketplaceResourceWithRawResponse:
    def __init__(self, marketplace: MarketplaceResource) -> None:
        self._marketplace = marketplace

        self.list_products = to_raw_response_wrapper(
            marketplace.list_products,
        )

    @cached_property
    def offers(self) -> OffersResourceWithRawResponse:
        return OffersResourceWithRawResponse(self._marketplace.offers)


class AsyncMarketplaceResourceWithRawResponse:
    def __init__(self, marketplace: AsyncMarketplaceResource) -> None:
        self._marketplace = marketplace

        self.list_products = async_to_raw_response_wrapper(
            marketplace.list_products,
        )

    @cached_property
    def offers(self) -> AsyncOffersResourceWithRawResponse:
        return AsyncOffersResourceWithRawResponse(self._marketplace.offers)


class MarketplaceResourceWithStreamingResponse:
    def __init__(self, marketplace: MarketplaceResource) -> None:
        self._marketplace = marketplace

        self.list_products = to_streamed_response_wrapper(
            marketplace.list_products,
        )

    @cached_property
    def offers(self) -> OffersResourceWithStreamingResponse:
        return OffersResourceWithStreamingResponse(self._marketplace.offers)


class AsyncMarketplaceResourceWithStreamingResponse:
    def __init__(self, marketplace: AsyncMarketplaceResource) -> None:
        self._marketplace = marketplace

        self.list_products = async_to_streamed_response_wrapper(
            marketplace.list_products,
        )

    @cached_property
    def offers(self) -> AsyncOffersResourceWithStreamingResponse:
        return AsyncOffersResourceWithStreamingResponse(self._marketplace.offers)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .fx import (
    FxResource,
    AsyncFxResource,
    FxResourceWithRawResponse,
    AsyncFxResourceWithRawResponse,
    FxResourceWithStreamingResponse,
    AsyncFxResourceWithStreamingResponse,
)
from .payments import (
    PaymentsResource,
    AsyncPaymentsResource,
    PaymentsResourceWithRawResponse,
    AsyncPaymentsResourceWithRawResponse,
    PaymentsResourceWithStreamingResponse,
    AsyncPaymentsResourceWithStreamingResponse,
)

__all__ = [
    "FxResource",
    "AsyncFxResource",
    "FxResourceWithRawResponse",
    "AsyncFxResourceWithRawResponse",
    "FxResourceWithStreamingResponse",
    "AsyncFxResourceWithStreamingResponse",
    "PaymentsResource",
    "AsyncPaymentsResource",
    "PaymentsResourceWithRawResponse",
    "AsyncPaymentsResourceWithRawResponse",
    "PaymentsResourceWithStreamingResponse",
    "AsyncPaymentsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["TransactionListParams"]


class TransactionListParams(TypedDict, total=False):
    category: str
    """Filter transactions by their AI-assigned or user-defined category."""

    end_date: Annotated[str, PropertyInfo(alias="endDate")]
    """Retrieve transactions up to this date (inclusive)."""

    limit: int
    """Maximum number of items to return in a single page."""

    max_amount: Annotated[int, PropertyInfo(alias="maxAmount")]
    """Filter for transactions with an amount less than or equal to this value."""

    min_amount: Annotated[int, PropertyInfo(alias="minAmount")]
    """Filter for transactions with an amount greater than or equal to this value."""

    offset: int
    """Number of items to skip before starting to collect the result set."""

    search_query: Annotated[str, PropertyInfo(alias="searchQuery")]
    """Free-text search across transaction descriptions, merchants, and notes."""

    start_date: Annotated[str, PropertyInfo(alias="startDate")]
    """Retrieve transactions from this date (inclusive)."""

    type: str
    """Filter transactions by type (e.g., income, expense, transfer)."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["MarketplaceListProductsParams"]


class MarketplaceListProductsParams(TypedDict, total=False):
    ai_personalization_level: Annotated[str, PropertyInfo(alias="aiPersonalizationLevel")]
    """Filter by AI personalization level (e.g., low, medium, high).

    'High' means highly relevant to user's specific needs.
    """

    category: str
    """
    Filter products by category (e.g., loans, insurance, credit_cards, investments).
    """

    limit: int
    """Maximum number of items to return in a single page."""

    min_rating: Annotated[int, PropertyInfo(alias="minRating")]
    """Minimum user rating for products (0-5)."""

    offset: int
    """Number of items to skip before starting to collect the result set."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .fraud import (
    FraudResource,
    AsyncFraudResource,
    FraudResourceWithRawResponse,
    AsyncFraudResourceWithRawResponse,
    FraudResourceWithStreamingResponse,
    AsyncFraudResourceWithStreamingResponse,
)
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["RiskResource", "AsyncRiskResource"]


class RiskResource(SyncAPIResource):
    @cached_property
    def fraud(self) -> FraudResource:
        return FraudResource(self._client)

    @cached_property
    def with_raw_response(self) -> RiskResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/diplomat-bit/aibank#accessing-raw-response-data-eg-headers
        """
        return RiskResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> RiskResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/diplomat-bit/aibank#with_streaming_response
        """
        return RiskResourceWithStreamingResponse(self)


class AsyncRiskResource(AsyncAPIResource):
    @cached_property
    def fraud(self) -> AsyncFraudResource:
        return AsyncFraudResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncRiskResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/diplomat-bit/aibank#accessing-raw-response-data-eg-headers
        """
        return AsyncRiskResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncRiskResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/diplomat-bit/aibank#with_streaming_response
        """
        return AsyncRiskResourceWithStreamingResponse(self)


class RiskResourceWithRawResponse:
    def __init__(self, risk: RiskResource) -> None:
        self._risk = risk

    @cached_property
    def fraud(self) -> FraudResourceWithRawResponse:
        return FraudResourceWithRawResponse(self._risk.fraud)


class AsyncRiskResourceWithRawResponse:
    def __init__(self, risk: AsyncRiskResource) -> None:
        self._risk = risk

    @cached_property
    def fraud(self) -> AsyncFraudResourceWithRawResponse:
        return AsyncFraudResourceWithRawResponse(self._risk.fraud)


class RiskResourceWithStreamingResponse:
    def __init__(self, risk: RiskResource) -> None:
        self._risk = risk

    @cached_property
    def fraud(self) -> FraudResourceWithStreamingResponse:
        return FraudResourceWithStreamingResponse(self._risk.fraud)


class AsyncRiskResourceWithStreamingResponse:
    def __init__(self, risk: AsyncRiskResource) -> None:
        self._risk = risk

    @cached_property
    def fraud(self) -> AsyncFraudResourceWithStreamingResponse:
        return AsyncFraudResourceWithStreamingResponse(self._risk.fraud)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .offers import (
    OffersResource,
    AsyncOffersResource,
    OffersResourceWithRawResponse,
    AsyncOffersResourceWithRawResponse,
    OffersResourceWithStreamingResponse,
    AsyncOffersResourceWithStreamingResponse,
)
from .marketplace import (
    MarketplaceResource,
    AsyncMarketplaceResource,
    MarketplaceResourceWithRawResponse,
    AsyncMarketplaceResourceWithRawResponse,
    MarketplaceResourceWithStreamingResponse,
    AsyncMarketplaceResourceWithStreamingResponse,
)

__all__ = [
    "OffersResource",
    "AsyncOffersResource",
    "OffersResourceWithRawResponse",
    "AsyncOffersResourceWithRawResponse",
    "OffersResourceWithStreamingResponse",
    "AsyncOffersResourceWithStreamingResponse",
    "MarketplaceResource",
    "AsyncMarketplaceResource",
    "MarketplaceResourceWithRawResponse",
    "AsyncMarketplaceResourceWithRawResponse",
    "MarketplaceResourceWithStreamingResponse",
    "AsyncMarketplaceResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .fx_get_rates_params import FxGetRatesParams as FxGetRatesParams
from .fx_get_rates_response import FxGetRatesResponse as FxGetRatesResponse
